[![Stars](https://img.shields.io/github/stars/laminlabs/lamindb?logo=GitHub&color=yellow)](https://github.com/laminlabs/lamindb)
[![codecov](https://codecov.io/gh/laminlabs/lamindb/branch/main/graph/badge.svg?token=VKMRJ7OWR3)](https://codecov.io/gh/laminlabs/lamindb)
[![pypi](https://img.shields.io/pypi/v/lamindb?color=blue&label=pypi%20package)](https://pypi.org/project/lamindb)

# LaminDB - Data framework for biology

LaminDB is an open-source Python framework to manage biological data & analyses in generic backends:

- Unify access to data & metadata across storage (files, arrays) & database (SQL) backends.
- Track data flow across notebooks, pipelines & UI.
- Manage registries for experimental metadata & ontologies.
- Validate & annotate data batches using in-house & public knowledge.
- Organize and share data across a mesh of LaminDB instances.

## Documentation

Read the [docs](https://lamin.ai/docs).
